<!DOCTYPE html>
<html>
<head>
    <title>ImgFixer - Processing Results</title>
    <link rel="stylesheet" type="text/css" href="/static/styles.css">
    <link rel="icon" type="image/x-icon" href="{{ url_for('static', path='favicon.ico') }}">
    <meta name="copyright" content="Copyright (c) 2025 Krishnakanth Allika, wheat-chop-octane@duck.com">
    <meta name="license" content="Licensed under the GNU General Public License v3 (GPLv3). This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program. If not, see https://www.gnu.org/licenses/gpl-3.0-standalone.html">
</head>
<body>
    <div class="container">
        <h2>ImgFixer - Processing Results</h2>
        
        <p>Total files: {{ total_files }}</p>
        <p>Number of traversed files: {{ traversed_files }}</p>
        <p>Number of renamed files: {{ renamed_files|length }}</p>
        {% if error %}
            <div class="error">
                <p>Error: {{ error[0] }} - {{ error[1] }}</p>
            </div>
        {% endif %}
        <h3>Renamed Files:</h3>
        <ul>
            {% for old_path, new_name in renamed_files %}
                <li>{{ old_path }} → {{ new_name }}</li>
            {% endfor %}
        </ul>
        <a href="/" class="button">Go Back</a>
    </div>
    <footer>
        <p>Copyright (c) 2025 Krishnakanth Allika, wheat-chop-octane [at] duck [dot] com, Licensed under the GNU General Public License v3 (GPLv3).</p>
    </footer>
</body>
</html>
