@import url('https://fonts.googleapis.com/css2?family=Fira+Code:wght@400;700&display=swap');

body {
    background-color: #121212;
    color: #e0e0e0;
    font-family: 'Fira Code', monospace;
    margin: 0;
    padding: 0;
    display: flex;
    flex-direction: column;
    min-height: 100vh;
    font-size: 0.8em; /* Set font size for all elements */
}

h1, h2 {
    font-size: 1.25rem; /* Set font size for headers */
}

h2 {
    color: #fc8686;
    text-align: center;
    margin-top: 20px;
}

.container {
    width: 100%;
    max-width: 800px;
    margin: auto;
    padding: 20px;
    background-color: #1e1e1e;
    border-radius: 8px;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
}

.form-group {
    margin-bottom: 20px;
}

label {
    display: block;
    margin-bottom: 8px;
    font-weight: bold;
}

input[type="text"] {
    width: calc(100% - 130px); /* Adjusted width to accommodate button */
    padding: 10px;
    border: 0.5px solid #fc8686; /* Added border */
    border-radius: 4px;
    background-color: #2c2c2c;
    color: #e0e0e0;
    display: inline-block;
    vertical-align: middle;
    margin-right: 10px; /* Added margin to create gap */
    font-family: 'Fira Code', monospace;
}

button, a.button {
    padding: 10px 20px;
    border: none;
    border-radius: 4px;
    background-color: #fc8686;
    color: #121212;
    cursor: pointer;
    transition: background-color 0.3s;
    display: inline-block;
    vertical-align: middle;
    font-family: 'Fira Code', monospace;
    text-align: center; /* Ensure text is centered for a.button */
    text-decoration: none; /* Remove underline for a.button */
}

button:hover, a.button:hover {
    background-color: #b65959;
}

ul {
    list-style-type: none;
    padding: 0;
}

li {
    background-color: #2c2c2c;
    margin: 5px 0;
    padding: 10px;
    border-radius: 4px;
}

footer {
    text-align: center;
    font-size: 0.8em;
    margin-top: 20px;
    padding: 10px 0;
    background-color: #1e1e1e;
    color: #e0e0e0;
    width: 100%;
    flex-shrink: 0;
}

.error {
    color: red;
}